#include "udf.h"

DEFINE_SOURCE(S_source,c,t,dS,eqn)
{
	real x[ND_ND];
	real source = 0;	
	real gamma = 1.5;
	real rho = 1.225;
	real U0 = 0.001487215;
	real pi = 3.141592654;
	
	C_CENTROID(x,c,t);
	
	source = gamma*(pi*pi*x[0]*x[0]-2)*cos(pi*x[1]) + 2*U0*rho*x[0]*x[1]*(2-x[1])*cos(pi*x[1]);
	
	dS[eqn] = 0;
	return source;
}

DEFINE_PROFILE(wylot_uds, t, i)
{
	real x[ND_ND];
	
	face_t f;
	begin_f_loop(f,t)
	{
		F_CENTROID(x,f,t);
		F_PROFILE(f,t,i) = 400*cos(3.14159*x[1]);
	}
	end_f_loop(f,t)
}

DEFINE_PROPERTY(lepkosc, c, t)
{
	real x[ND_ND];
	//F_CENTROID(x,c,t);
	real nu = 2*1.789e-5;
	return nu;
}

/////////////////////////////////////////////////////////////////////////////////////////////

DEFINE_PROFILE(predkosc_wlot, t, i)
{
	real x[ND_ND];
	real y;
	
	face_t f;
	
	begin_f_loop(f,t)
	{
		F_CENTROID(x,f,t);
		y = x[1];
		F_PROFILE(f,t,i) = 0.15*y*(2-y);
	}
	end_f_loop(f,t);
}

DEFINE_PROFILE(eps_bc, t, i)
{
	cell_t c0;
	real x[ND_ND];
	real y, k, nu;
	face_t f;
	
	nu = 1.7894e-5;
	
	begin_f_loop(f,t)
	{
		// Znajdz numer komorki
		c0 = F_C0(f,t);
		//printf("%d ", c0);
		
		// Sprawdz odleglosc komorki od brzegu oraz wartosc k
		C_CENTROID(x,c0,THREAD_T0(t));
		
		//y = x[1];
		
		//if((2-y) < y)
		//{
		//	y = 2-y;
		//}
		//printf("y = %f\n", y);
		
		//y = C_WALL_DIST(c0, THREAD_T0(t));
		
		//printf("%lf ", y);
		if(x[0] < 0.01) y = 0.01-x[1];
		else if(x[0] >= 0.01) y = 0.04-x[0];
		
		k = C_UDSI(c0, THREAD_T0(t), 0);
		
		F_PROFILE(f,t,i) = 2*nu*k/(y*y); // 0.2 jest tu bez uzasadnienia!
	}
	end_f_loop(f,t);
	//printf("Hello world!\n");
}

DEFINE_PROPERTY(turbulent_viscosity, c, t)
{
	real x[ND_ND];
	real mut, mu, rho, Cmu, k, epsilon;
	
	mu = 1.7894e-5;
	rho = 1.225;
	Cmu = 0.09;
	
	k = C_UDSI(c,t,0);
	epsilon = C_UDSI(c,t,1);
	
	mut = rho*Cmu*k*k/epsilon;
	C_UDMI(c,t,0) = mut;
	
	return mu+mut;
}

DEFINE_SOURCE(k_production,c,t,dS,eqn)
{
	real source;
	real rho;
	real epsilon, Gk, mut, ux, uy, vx, vy, s11, s12, s21, s22;
	
	source = 0;
	rho = 1.225;
	
	// Policz gradienty
	ux = C_U_G(c,t)[0];
	uy = C_U_G(c,t)[1];
	vx = C_V_G(c,t)[0];
	vy = C_V_G(c,t)[1];
	
	s11 = ux;
	s12 = 0.5*(uy+vx);
	s21 = s12;
	s22 = vy;
	
	mut = C_UDMI(c,t,0);
	//S = Strainrate_Mag(c,t);
	Gk = mut*2.0*(s11*s11+s12*s12+s21*s21+s22*s22);
	//Gk = mut*SQR(S);
	epsilon = C_UDSI(c,t,1);
	
	//C_UDMI(c,t,1) = C_WALL_DIST(c,t);
	//printf("%lf\n", C_WALL_DIST(c,t));
	
	return Gk - rho*epsilon;
}

DEFINE_SOURCE(eps_production, c, t, dS, eqn)
{
	real epsilon, k, C1eps, Gk, C2eps, rho, mut, s11, s12, s21, s22, ux, uy, vx, vy;
	
	C1eps = 1.44;
	C2eps = 1.92;
	rho = 1.225;
	
	ux = C_U_G(c,t)[0];
	uy = C_U_G(c,t)[1];
	vx = C_V_G(c,t)[0];
	vy = C_V_G(c,t)[1];
	
	s11 = ux;
	s12 = 0.5*(uy+vx);
	s21 = s12;
	s22 = vy;
	
	mut = C_UDMI(c,t,0);
	Gk = mut*2.0*(s11*s11+s12*s12+s21*s21+s22*s22);
	
	k = C_UDSI(c,t,0);
	epsilon = C_UDSI(c,t,1);
	
	return C1eps*epsilon/k*Gk - C2eps*rho*epsilon*epsilon/k;
}

DEFINE_PROPERTY(k_diffusivity, c, t)
{
	real sigmak;
	real mu, mut;
	
	mu = 1.7984e-5;
	sigmak = 1.0;
	mut = C_UDMI(c,t,0);
	
	return mu+mut/sigmak;
}

DEFINE_PROPERTY(eps_diffusivity, c, t)
{
	real mu, mut, sigmaeps;
	
	mu = 1.7984e-5;
	sigmaeps = 1.3;
	mut = C_UDMI(c,t,0);
	
	return mu+mut/sigmaeps;
}